! This program makes a pointfile that can be used to retrieve hybrid 
! simulation data from the Finnish hybrid web archive.
!
! The cheese inputfile, i.e. inputcheese.m, is read and an output file 
! called pointfile.cheese.dat is created


program pointfilemaker

  use SpecificTypes

  implicit none
! input variables
  type (InputGeneral) inpar

! Other variables
  integer Nretries, attempts, gl, ii

  type (GridLevel), allocatable :: grid(:)

  double precision Lx, Ly, Lz, dxyz(3)

  double precision, allocatable :: X(:), Y(:), Z(:)


! Initialise a couple of things
  parameter(Nretries = 10)


! Read input data
  attempts = 0
  call GetGeneralInput(inpar, attempts, Nretries)
  allocate(grid(inpar%Ngridlevels))
  attempts = 0
  call GetGridLevels('', inpar%Ngridlevels, grid, attempts, Nretries)

! Loop over all the grid levels
  do gl = 1, inpar%Ngridlevels

! System size
     Lx = grid(gl)%xmax - grid(gl)%xmin
     Ly = grid(gl)%ymax - grid(gl)%ymin
     Lz = grid(gl)%zmax - grid(gl)%zmin

! Set grid cell size
     dxyz(1) = Lx/(grid(gl)%Nx-1)
     dxyz(2) = Ly/(grid(gl)%Ny-1)
     dxyz(3) = Lz/(grid(gl)%Nz-1)

! Allocate and create x, y, and z vectors for the grid
     allocate(X(grid(gl)%Nx))
     allocate(Y(grid(gl)%Ny))
     allocate(Z(grid(gl)%Nz))
     do ii = 1, grid(gl)%Nx
        X(ii) = grid(gl)%xmin + dxyz(1)*dble(ii-1)
     end do
     do ii = 1, grid(gl)%Ny
        Y(ii) = grid(gl)%ymin + dxyz(2)*dble(ii-1)
     end do
     do ii = 1, grid(gl)%Nz
        Z(ii) = grid(gl)%zmin + dxyz(3)*dble(ii-1)
     end do

! Now we should be ready to write the file
     attempts = 0
     call Dumppoints('pointfiles/', grid(gl)%Nx, X, grid(gl)%Ny, Y, &
          grid(gl)%Nz, Z, gl, attempts, Nretries)

! Deallocate before starting over
     deallocate(X)
     deallocate(Y)
     deallocate(Z)

  end do

end program pointfilemaker

