% cheese_a3pss15dustmaps plots outputs of statistical data from test particle
% simulations. This is a particular figure designed for publication in
% Planetary and Space Science. 
%
% HG 2015-06-09


figure(80000);clf
set(gcf,'paperpositionmode','auto','renderer','zbuffer')
set(gcf,'position',[6 371 1050 900])

c2=[];
for nn=1:2
  c1=jet(16*4^nn);
  c2=[c2;c1((1+(nn-1)*2*4^nn):nn*2*4^nn,:)];
end
c2=[c2;c1(nn*2*4^nn+1:end,:)];

c3=[];
for nn=1:3
  c1=jet(16*4^nn);
  c3=[c3;c1((1+(nn-1)*2*4^nn):nn*2*4^nn,:)];
end
c3=[c3;c1(nn*2*4^nn+1:end,:)];

c4=[];
for nn=1:4
  c1=jet(16*4^nn);
  c4=[c4;c1((1+(nn-1)*2*4^nn):nn*2*4^nn,:)];
end
c4=[c4;c1(nn*2*4^nn+1:end,:)];

c5=[];
for nn=1:5
  c1=jet(16*4^nn);
  c5=[c5;c1((1+(nn-1)*2*4^nn):nn*2*4^nn,:)];
end
c5=[c5;c1(nn*2*4^nn+1:end,:)];

spno = 0; % subplot number
for jj=[11:13 15:17 31:33]
  spno=spno+1;
  thedirectory = ['~/cheese/a3/pss15/collection/pss' num2str(jj,'%2.2d')];
  cd(thedirectory)
  fid=fopen('inputcheese.m');
  theline=fgetl(fid);
  if length(theline)<5,
    theline=[theline '     '];
  end
  while ~(strcmp(theline(1:5),'%PARA') | strcmp(theline(1:5),'%para'))
    theline=fgetl(fid);
    if length(theline)<5,
      theline=[theline '     '];
    end
  end
  while ~(strcmp(theline(1:4),'%END') | strcmp(theline(1:4),'%end'))
    eval(theline)
    theline=fgetl(fid);
    if length(theline)<4,
      theline=[theline '    '];
    end
  end
  Lx=xmax-xmin;
  Ly=ymax-ymin;
  Lz=zmax-zmin;
  dx = Lx/(Nx-1);
  dy = Ly/(Ny-1);
  dz = Lz/(Nz-1);
  x = xmin + dx*[0:Nx-1];
  y = ymin + dy*[0:Ny-1];
  z = zmin + dz*[0:Nz-1];
  fclose(fid);

  y1=mean([zmin zmax]);

  dd=dir('outp/testpdens*.mat');
  Np=str2num(dd(end).name(10:19));

  % Assemble filenames
  nstring = ['outp/testpdens',num2str(Np,'%0.10d') '.cheese.mat'];


  % Load fields
  load(nstring)

  Nmidy=floor((y1-ymin)/dy+1);
  fract = (y1-ymin)/dy+1 - Nmidy;

  ha(spno)=axes('position', ...
                [0.04+0.33*mod(spno-1,3) 0.71-floor((spno-1)/3)*0.325 ...
                 0.215 0.27]);
  pp=[];pp(:,:)=0.5*(n(:,Nmidy,:)*(1-fract)+n(:,Nmidy+1,:)*fract)/Np;pp=pp.';
  nmin=min(min(min(pp)));
  nmax=max(max(max(pp)));
  pp(isnan(pp))=nmax+1e16;
  ss=size(pp);
  pp=[pp zeros(ss(1),1);zeros(1,ss(2)+1)];
  xplot=[xmin-0.5*dx (x+0.5*dx)]*1e-3;
  zplot=[zmin-0.5*dz (z+0.5*dz)]*1e-3;
  surf(xplot,zplot,pp)
  view(2)
  set(gca,'fontname','times','fontsize',14)
  shading flat
  view(2)
  axis equal
  axis([min(xplot) max(xplot) min(zplot) max(zplot)])
  hh=colorbar;
  hhpos=get(hh,'position');
  set(hh,'position',[hhpos(1)+0.05 hhpos(2)-0.03 0.01 hhpos(4)*1.25]);
  set(hh,'fontname','times','fontsize',16)
  ylabel(hh,'n/Q_{d}   [m^{-3}s]','fontname','times','fontsize',18)
  hhylpos=get(get(hh,'ylabel'),'pos');
  set(get(hh,'ylabel'),'position',[hhylpos(1)*1.2 hhylpos(2:3)])
  xlabel('x   [km]','fontname','times','fontsize',18)
  ylabel('z   [km]','fontname','times','fontsize',18)
  hhylpos=get(get(ha(spno),'ylabel'),'pos');
  set(get(ha(spno),'ylabel'),'position',[hhylpos(1)*0.92 hhylpos(2:3)])

  colormap(c5)

end

rd = [10 10 10 1 2 3 1 2 3];
vr = [50 300 700 700 700 700 700 700 700];
placement = [0 0 0 0 0 0 0.55 0.55 0.55];
for spno=1:length(ha)
  aa=axis(ha(spno));
  text(aa(1)+0.05*diff(aa(1:2)),aa(3)+0.9*diff(aa(3:4)), ...
       ['(' char(96+spno) ')'],'parent',ha(spno), ...
       'color','w','fontname','times','fontsize',18)

  text(aa(1)+0.1*diff(aa(1:2)),aa(3)+(0.2+placement(spno))*diff(aa(3:4)), ...
       ['r_{d} = ' num2str(rd(spno)) ' nm'],'parent',ha(spno), ...
       'color','w','fontname','times','fontsize',18)

  text(aa(1)+0.1*diff(aa(1:2)),aa(3)+(0.05+placement(spno))*diff(aa(3:4)), ...
       ['v_{r} = ' num2str(vr(spno)) ' m/s'],'parent',ha(spno), ...
       'color','w','fontname','times','fontsize',18)

  % E-field arrow
  axes(ha(spno));
  hold on
  pil(2.5e4*(1+1i),1i,5e3,'w');
  plot([2.5e4*(1+1i) 2.5e4+1.0e4*1i],'w','linewidth',2)
  text(2.0e4,2.5e4,'E','color','w','fontname','times','fontsize',18)
  % B-field cross and ring
  zBc=2.5e4*(1-1i); rB=2.5e3;
  zB=rB*exp(1i*[0:360]*pi/180) + zBc;
  plot(zB,'w','linewidth',2)
  plot(zBc+rB*[(-1+1i) (1-1i)]/sqrt(2),'w','linewidth',2)
  plot(zBc+rB*[(-1-1i) (1+1i)]/sqrt(2),'w','linewidth',2)
  text(2.0e4,-2.1e4,'B','color','w','fontname','times','fontsize',18)


end


if 3==4
  ccc=pwd;
  cd ~
  print -f80000 -depsc2 fig-dustmaps-revised.eps
  cd(ccc)
end
