% cheese_a3pss15fields plots E- and B-fields for use in the PSS paper in
% 2015.
%
% HG 2015-06-08


inputcheese;

z1=0;y1=0;gl=1;

% Assemble filenames


% Load fields
load('outp/grid.cheese.mat');

Nmidy=floor((y1-fgrid(gl).ymin)/fgrid(gl).dy+1);% round downward, then
if abs(fgrid(gl).y(Nmidy)-y1)>fgrid(gl).dy*0.1  % take mean of this and
  Nmidyvec = [Nmidy:Nmidy+1];                   % one higher, unless
else                                            % there is a point at y1
  Nmidyvec = Nmidy;                             % or z1 in which case we
end                                             % use that point


figure(100);clf
set(gcf,'paperpositionmode','auto','renderer','zbuffer')
set(gcf,'position',[364 551 1313 800])


ha(1)=axes('position',[0.032 0.58 0.25 0.36]);
pp=[];pp(:,:)=mean(fgrid(gl).By(:,Nmidyvec,:),2)*1e9;pp=pp.';
ss=size(pp);
Bmax=max(max(max(pp)));
Bmin=min(min(min(pp)));
pp=[pp zeros(ss(1),1);zeros(1,ss(2)+1)];
pp(isnan(pp))=Bmax+1e16;
xplot=[fgrid(gl).xmin-0.5*fgrid(gl).dx (fgrid(gl).x+0.5*fgrid(gl).dx)]*1e-3;
zplot=[fgrid(gl).zmin-0.5*fgrid(gl).dz (fgrid(gl).z+0.5*fgrid(gl).dz)]*1e-3;
surf(xplot,zplot,pp)
view(2)
set(gca,'fontname','times','fontsize',14)
shading flat
view(2)
axis equal
axis([min(xplot) max(xplot) min(zplot) max(zplot)])
hh=colorbar;
set(hh,'fontname','times','fontsize',14)
hhpos=get(hh,'pos');
set(hh,'pos',[hhpos(1)+0.035 hhpos(2)-0.015 0.008 0.35])
hhyl=ylabel(hh,'B_{y}   [nT]','fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
xlabel('x   [km]','fontname','times','fontsize',18)
hhyl=ylabel('z   [km]','fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
set(hhyl,'pos',[-3.3e4 -0.0187])
title(['B_{y} at y=' num2str(mean(fgrid(gl).y(Nmidyvec))) 'm'], ...
      'fontname','times','fontsize',18)
cc=colormap(jet(64));
cc=[cc;1 1 1];sc=size(cc);colormap(cc);
caxis([Bmin Bmax+(Bmax-Bmin)/(sc(1)-1)+1e-10])

ha(2)=axes('position',[0.36 0.58 0.25 0.36]);
pp=[];pp(:,:)=mean(fgrid(gl).Ez(:,Nmidyvec,:),2)*1e3;pp=pp.';
ss=size(pp);
Emax=max(max(max(pp)));
Emin=min(min(min(pp)));
pp=[pp zeros(ss(1),1);zeros(1,ss(2)+1)];
pp(isnan(pp))=Emax+1e16;
xplot=[fgrid(gl).xmin-0.5*fgrid(gl).dx (fgrid(gl).x+0.5*fgrid(gl).dx)]*1e-3;
zplot=[fgrid(gl).zmin-0.5*fgrid(gl).dz (fgrid(gl).z+0.5*fgrid(gl).dz)]*1e-3;
surf(xplot,zplot,pp)
view(2)
set(gca,'fontname','times','fontsize',14)
shading flat
view(2)
axis equal
axis([min(xplot) max(xplot) min(zplot) max(zplot)])
hh=colorbar;
set(hh,'fontname','times','fontsize',14)
hhpos=get(hh,'pos');
set(hh,'pos',[hhpos(1)+0.035 hhpos(2)-0.015 0.008 0.35])
hhyl=ylabel(hh,'E_{z}   [mV/m]','fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
set(hhyl,'pos',[12 1.6])
xlabel('x   [km]','fontname','times','fontsize',18)
hhyl=ylabel('z   [km]','fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
set(hhyl,'pos',[-3.3e4 -0.0187])
title(['E_{z} at y=' num2str(mean(fgrid(gl).y(Nmidyvec))) 'm'], ...
      'fontname','times','fontsize',18)
cc=colormap(jet(64));
cc=[cc;1 1 1];sc=size(cc);colormap(cc);
caxis([Emin Emax+(Emax-Emin)/(sc(1)-1)+1e-10])

ha(3)=axes('position',[0.69 0.58 0.25 0.36]);
pp=[];pp(:,:)=log10(mean(fgrid(gl).particle(2).n(:,Nmidyvec,:),2));
pp=pp.';
ss=size(pp);
nmax=max(max(max(pp(~isinf(pp)))));
nmin=min(min(min(pp(~isinf(pp)))));
pp=[pp zeros(ss(1),1);zeros(1,ss(2)+1)];
pp(isnan(pp))=nmax+1e16;
xplot=[fgrid(gl).xmin-0.5*fgrid(gl).dx (fgrid(gl).x+0.5*fgrid(gl).dx)]*1e-3;
zplot=[fgrid(gl).zmin-0.5*fgrid(gl).dz (fgrid(gl).z+0.5*fgrid(gl).dz)]*1e-3;
surf(xplot,zplot,pp)
view(2)
set(gca,'fontname','times','fontsize',14)
shading flat
view(2)
axis equal
axis([min(xplot) max(xplot) min(zplot) max(zplot)])
hh=colorbar;
set(hh,'fontname','times','fontsize',14)
hhpos=get(hh,'pos');
set(hh,'pos',[hhpos(1)+0.035 hhpos(2)-0.015 0.008 0.35])
hhyl=ylabel(hh,'lg(n_{H_{2}O^{+}}/m^{-3})', ...
            'fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
set(hhyl,'pos',[10 4.49])
xlabel('x   [km]','fontname','times','fontsize',18)
hhyl=ylabel('z   [km]','fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
set(hhyl,'pos',[-3.3e4 -0.0187])
title(['H_{2}O^{+} density at y=' ...
       num2str(mean(fgrid(gl).y(Nmidyvec))) 'm'], ...
      'fontname','times','fontsize',18)
cc=colormap(jet(64));
cc=[cc;1 1 1];sc=size(cc);colormap(cc);
caxis([nmin nmax+(nmax-nmin)/(sc(1)-1)+1e-10])

% We set gl=3 and do it all over again for a closeup
gl=3;
Nmidy=floor((y1-fgrid(gl).ymin)/fgrid(gl).dy+1);% round downward, then
if abs(fgrid(gl).y(Nmidy)-y1)>fgrid(gl).dy*0.1  % take mean of this and
  Nmidyvec = [Nmidy:Nmidy+1];                   % one higher, unless
else                                            % there is a point at y1
  Nmidyvec = Nmidy;                             % or z1 in which case we
end                                             % use that point

ha(4)=axes('position',[0.06 0.09 0.22 0.36]);
pp=[];pp(:,:)=mean(fgrid(gl).By(:,Nmidyvec,:),2)*1e9;pp=pp.';
ss=size(pp);
Bmax=max(max(max(pp)));
Bmin=min(min(min(pp)));
pp=[pp zeros(ss(1),1);zeros(1,ss(2)+1)];
pp(isnan(pp))=Bmax+1e16;
xplot=[fgrid(gl).xmin-0.5*fgrid(gl).dx (fgrid(gl).x+0.5*fgrid(gl).dx)]*1e-3;
zplot=[fgrid(gl).zmin-0.5*fgrid(gl).dz (fgrid(gl).z+0.5*fgrid(gl).dz)]*1e-3;
surf(xplot,zplot,pp)
view(2)
set(gca,'fontname','times','fontsize',14)
shading flat
view(2)
axis equal
axis([min(xplot) max(xplot) min(zplot) max(zplot)])
hh=colorbar;
set(hh,'fontname','times','fontsize',14)
hhpos=get(hh,'pos');
set(hh,'pos',[hhpos(1)+0.035 hhpos(2)-0.03 0.008 0.35])
hhyl=ylabel(hh,'B_{y}   [nT]','fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
xlabel('x   [km]','fontname','times','fontsize',18)
hhyl=ylabel('z   [km]','fontname','times','fontsize',18);
cc=colormap(jet(64));
cc=[cc;1 1 1];sc=size(cc);colormap(cc);
caxis([Bmin Bmax+(Bmax-Bmin)/(sc(1)-1)+1e-10])

ha(5)=axes('position',[0.385 0.09 0.22 0.36]);
pp=[];pp(:,:)=mean(fgrid(gl).Ez(:,Nmidyvec,:),2)*1e3;pp=pp.';
ss=size(pp);
Emax=max(max(max(pp)));
Emin=min(min(min(pp)));
pp=[pp zeros(ss(1),1);zeros(1,ss(2)+1)];
pp(isnan(pp))=Emax+1e16;
xplot=[fgrid(gl).xmin-0.5*fgrid(gl).dx (fgrid(gl).x+0.5*fgrid(gl).dx)]*1e-3;
zplot=[fgrid(gl).zmin-0.5*fgrid(gl).dz (fgrid(gl).z+0.5*fgrid(gl).dz)]*1e-3;
surf(xplot,zplot,pp)
view(2)
set(gca,'fontname','times','fontsize',14)
shading flat
view(2)
axis equal
axis([min(xplot) max(xplot) min(zplot) max(zplot)])
hh=colorbar;
set(hh,'fontname','times','fontsize',14)
hhpos=get(hh,'pos');
set(hh,'pos',[hhpos(1)+0.04 hhpos(2)-0.03 0.008 0.35])
hhyl=ylabel(hh,'E_{z}   [mV/m]','fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
set(hhyl,'pos',[12 1.6])
xlabel('x   [km]','fontname','times','fontsize',18)
hhyl=ylabel('z   [km]','fontname','times','fontsize',18);
cc=colormap(jet(64));
cc=[cc;1 1 1];sc=size(cc);colormap(cc);
caxis([Emin Emax+(Emax-Emin)/(sc(1)-1)+1e-10])

ha(6)=axes('position',[0.725 0.09 0.22 0.36]);
pp=[];pp(:,:)=log10(mean(fgrid(gl).particle(2).n(:,Nmidyvec,:),2));
pp=pp.';
ss=size(pp);
nmax=max(max(max(pp(~isinf(pp)))));
nmin=min(min(min(pp(~isinf(pp)))));
pp=[pp zeros(ss(1),1);zeros(1,ss(2)+1)];
pp(isnan(pp))=nmax+1e16;
xplot=[fgrid(gl).xmin-0.5*fgrid(gl).dx (fgrid(gl).x+0.5*fgrid(gl).dx)]*1e-3;
zplot=[fgrid(gl).zmin-0.5*fgrid(gl).dz (fgrid(gl).z+0.5*fgrid(gl).dz)]*1e-3;
surf(xplot,zplot,pp)
view(2)
set(gca,'fontname','times','fontsize',14)
shading flat
view(2)
axis equal
axis([min(xplot) max(xplot) min(zplot) max(zplot)])
cc=colormap(jet(64));
cc=[cc;1 1 1];sc=size(cc);colormap(cc);
caxis([nmin nmax+(nmax-nmin)/(sc(1)-1)+1e-10])

hh=colorbar;
set(hh,'fontname','times','fontsize',14)
hhpos=get(hh,'pos');
set(hh,'pos',[hhpos(1)+0.035 hhpos(2)-0.03 0.008 0.35])
hhyl=ylabel(hh,'lg(n_{H_{2}O^{+}}/m^{-3})', ...
            'fontname','times','fontsize',18);
hhylpos=get(hhyl,'pos');
cax=caxis;
set(hhyl,'pos',[10.5 mean(cax)])
xlabel('x   [km]','fontname','times','fontsize',18)
hhyl=ylabel('z   [km]','fontname','times','fontsize',18);





for ii=1:length(ha)
  aa=axis(ha(ii));
  text(aa(1)+0.05*diff(aa(1:2)),aa(3)+0.9*diff(aa(3:4)),15, ...
       ['(' char(96+ii) ')'],'parent',ha(ii), ...
       'color','k','fontname','times','fontsize',18)
end


if 3==4
  ccc=pwd;
  cd ~
  print -f100 -depsc2 fig-model-revised.eps
  cd(ccc)
end % end if 3==4
