%PARAMETERS
NhybSpecies = 3;          % Number of species in the hybrid simulation
Npart  = 100;         % Number of trajectories to compute
Nsteps = 10000000;        % Maximum number of time steps per trajectory
Ngridlevels=3;            % Number of grid refinement levels (total)
dt     = 5.0e0;           % Time step [s]
mass   = 2.8274e-22;      % Ion mass [kg]  (dust: radius 3 nanometres)
charge = 1.7624e-18;      % Ion charge [As] (11 elementary charges)
robst = 5e3;              % Obstacle radius below which no trajectories
                          % are calculated. [m]
initialiser = 3;          % Initialisation method
                          % 1: Maxwellian in cube; parameters as above
                          % 2: Read position, v_par, vth_perp from file;
                          %    one particle per line.
                          % 3: Maxwellian in surface sector of a sphere
                          %    of radius rsource. A radial velocity
                          %    offset may be specified using the vrbulk
                          %    variable. 
Xcube   = 1.0e7;        % x-coordinate [m] for centre of cube (initialiser=1)
Ycube   = 0.0e3;        % y-coordinate [m] for centre of cube (initialiser=1)
Zcube   = 0.0e4;        % z-coordinate [m] for centre of cube (initialiser=1)
vth     = 1.0e0;        % Thermal speed [m/s] for Maxwellian (initialiser=1,3)
                        % f(vx) ~ exp(-vx^2/vth^2) etc. => vth=sqrt(2*kB*T/m)
Lside  = 1e4;           % Side of cube where particles start [m] (initialiser=1)
vxbulk  = 0.0e4;        % x-comp [m/s] of bulk vel in GSE syst (initialiser=1)
vybulk  = 0.0e5;        % y-comp [m/s] of bulk vel in GSE syst (initialiser=1)
vzbulk  = 0.0e6;        % z-comp [m/s] of bulk vel in GSE syst (initialiser=1)
rsource = 1.5e5;        % radius of the source shere [m] (initialiser=3)
vrbulk  = 7.0e2;        % radial bulk velocity [m/s] (initialiser=3)
scdatafilename='rosetta.dat'; % Input file name for initialiser=2
thetamin = 0.0;         % Minimum angle to x axis for initialiser=3, degrees
thetamax = 180.0;       % Maximum angle to x axis for initialiser=3, degrees
azmin = 0.0;            % Minimum azimuth angle for initialiser=3, degrees
azmax = 360.0;          % Maximum azimuth angle for initialiser=3, degrees
                        % The y axis has theta=90 and azimuth=0,
                        % whereas the z axis has theta=90 and azimuth=90.

% ----- Fluctuation model parameters ----- %
Efluctuations = 'no';      % If 'yes' a prescribed fluctuation E-field is used
rinfluct = 1500e3;         % The field is applied between the cometocentric
routfluct = 2.0e7;         % distances rinfluct and routfluct with a half
                           % wavelength sinusoidal profile in between.
E1x = 0.0e-4;              % Peak primary fluctuation field in the x-direction.
E1y = 0.0e-4;              % Peak primary fluctuation field in the y-direction.
E1z = 0.0e-4;              % Peak primary fluctuation field in the z-direction.
ffluct = 5.0e-3;           % Frequency of the fluctuations
usealpha = 'yes';          % If 'yes' the field is adjusted to the specified
alpha = 0.0e-1;            % angle [radians] between E and perpendicular
                           % (to B) direction.

% ----- Photon pressure ---- %
includephotonpressure = 'no'; % If 'yes', the force Flight is included 
Flight = 0.0e-16;          % Force on dust particle from radiation pressure

% ----- Cheddar specific parameters ---- %
Nprobes = 0;               % Number of distribution function probes for
                           % which details are specified below
startfromdumpfile='no';    % If 'yes' the particle initial positions and
                           % velocities are read from the dumps directory.
dump_period_dump = 100000; % Number of iterations between dumps you can
                           % start from.
% These grid parameters are for the output grid only.
Nx = 192;                   % Number of grid points in x-direction 
Ny = 96;                    % Number of grid points in y-direction 
Nz = 192;                   % Number of grid points in z-direction 
xmin = -28746050;          % Lower x-boundary [m]
xmax =  28746050;          % Upper x-boundary [m]
ymin = -28746050;          % Lower y-boundary [m]
ymax =  28746050;          % Upper y-boundary [m]
zmin = -28746050;          % Lower z-boundary [m]
zmax =  28746050;          % Upper z-boundary [m]



% -------- Common hybrid files --------- %
magfilename='Mag_ave_hybstate_00300000.hc'; % Magnetic f. hybrid file
curfilename='Cur_ave_hybstate_00300000.hc'; % Current hybrid file
% If either of magfilename or curfilename are absent, the corresponding
% quantity is looked for in the particle files. If it is missing there
% too, it is set to zero.

%--------- Data save parameters below ---------%
saving_step_length = 0.0e3;   % step length between two saved trajectory 
                              % positions [m]
%END

%GRID LEVEL 1: coarsest level
Nx = 50;                  % Number of field grid points in x-direction 
Ny = 50;                  % Number of field grid points in y-direction 
Nz = 50;                  % Number of field grid points in z-direction 
xmin = -29653820;         % Lower x-boundary [m]
xmax =  29653820;         % Upper x-boundary [m]
ymin = -29653820;         % Lower y-boundary [m]
ymax =  29653820;         % Upper y-boundary [m]
zmin = -29653820;         % Lower z-boundary [m]
zmax =  29653820;         % Upper z-boundary [m]
%END

%GRID LEVEL 2
Nx = 21;                  % Number of field grid points in x-direction 
Ny = 21;                  % Number of field grid points in y-direction 
Nz = 21;                  % Number of field grid points in z-direction 
xmin =  -6051800;         % Lower x-boundary [m]
xmax =   6051800;         % Upper x-boundary [m]
ymin =  -6051800;         % Lower y-boundary [m]
ymax =   6051800;         % Upper y-boundary [m]
zmin =  -6051800;         % Lower z-boundary [m]
zmax =   6051800;         % Upper z-boundary [m]
%END

%GRID LEVEL 3
Nx = 21;                  % Number of field grid points in x-direction 
Ny = 21;                  % Number of field grid points in y-direction 
Nz = 21;                  % Number of field grid points in z-direction 
xmin =   -3025900;        % Lower x-boundary [m]
xmax =    3025900;        % Upper x-boundary [m]
ymin =   -3025900;        % Lower y-boundary [m]
ymax =    3025900;        % Upper y-boundary [m]
zmin =   -3025900;        % Lower z-boundary [m]
zmax =    3025900;        % Upper z-boundary [m]
%END


%SPECIES 1: protons
hybfilename = 'H+_ave_hybstate_00300000.hc'; % Hybrid data file name
                                             % without the level suffix
chargestate = 1.0d0;             % Number of elementary charges per ion
hybiteration = 300000;
%END

%SPECIES 2: water ions
hybfilename = 'H2O+_ave_hybstate_00300000.hc'; % Hybrid data file name
                                               % without the level suffix
chargestate = 1.0d0;             % Number of elementary charges per ion
hybiteration = 300000;
%END

%SPECIES 3: alpha particles
hybfilename = 'He++_ave_hybstate_00300000.hc'; % Hybrid data file name
                                               % without the level suffix
chargestate = 2.0d0;             % Number of elementary charges per ion
hybiteration = 300000;
%END

%PROBE 1
Nvx = 100;       % Number of grid points in vx direction
Nvy = 100;       % Number of grid points in vy direction
Nvz = 100;       % Number of grid points in vz direction
vxmin = -1.2e5;  % Minimum velocity in vx direction
vxmax = -9.0e4;  % Maximum velocity in vx direction
vymin = -0.0e4;  % Minimum velocity in vy direction
vymax =  5.0e3;  % Maximum velocity in vy direction
vzmin =  5.0e4;  % Minimum velocity in vz direction
vzmax =  9.0e4;  % Maximum velocity in vz direction
xc = -6.622e6;   % x coordinate of probe centre
yc =  0.0e6;     % y coordinate of probe centre
zc =  3.311e6;   % z coordinate of probe centre
rprobe = 5.0e5;  % Probe radius
%END
